@@ -11,6 +11,11 @@ import publication
 import aws_cdk.cloud_assembly_schema
 import aws_cdk.cx_api
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/core", "1.34.0", __name__[0:-6], "core@1.34.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
